@@ -1,3 +1,5 @@
+if(Sys.getenv("NOT_CRAN")==TRUE){
+
 library(ctsem)
 library(testthat)
 set.seed(1)
@@ -46,12 +48,12 @@ MANIFESTVAR=diag(0.5,1),
  checkm$pars[c(-1,-7) ,c('TI1_effect')] <- FALSE
  checkm$pars$meanscale[c(1,7)] <- 1
 
-tfit<-ctStanFit(tdat,checkm,iter=400, warmup=380,chains=2,plot=TRUE,optimize=T,isloops=3,nopriors=F,verbose=0)
+tfit<-ctStanFit(tdat,checkm,iter=400, warmup=380,chains=2,optimize=T,isloops=3,nopriors=F,verbose=0)
 s=summary(tfit)
 
 expect_equal(s$tipreds[2,'mean'],5,tolerance=.1)
 
-tfit<-ctStanFit(tdat,checkm,iter=400, warmup=380,chains=2,plot=TRUE,optimize=T,isloops=3,nopriors=F,verbose=0,
+tfit<-ctStanFit(tdat,checkm,iter=400, warmup=380,chains=2,optimize=T,isloops=3,nopriors=F,verbose=0,
   nlcontrol=list(nldynamics=TRUE,nlmeasurement=TRUE))
 s=summary(tfit)
 
@@ -62,3 +64,4 @@ s=summary(tfit)
 
 expect_equal(s$tipreds[2,'mean'],5,tolerance=.1)
 })
+}
